# Python ActiveX Scripting Demonstation

Congratulations on installing the Python ActiveX Scripting Engine

Be warned that there is a privacy concern with this engine. Please read this information, including how to disable the feature.

### Object model

Except as described below, the object module exposed should be similar to that exposed by Visual Basic, etc. Due to the nature of ActiveX Scripting, the details for each host are different, but Python should work "correctly".

The object model exposed via Python for MSIE is not as seamless as VB. The biggest limitation is the concept of a "local" namespace. For example, in VB, you can code `text="Hi there"`, but in Python, you must code `MyForm.ThisButton.Text="Hi There"`. See the foo2 sample for futher details.

### Known bugs and problems

- This release seems to have broken Aaron's mouse-trace sample. No idea why, and I'm supposed to be looking into it.

- Builtin objects such as MARQUEE are giving me grief. Objects accessed via forms are generally no problem.

- If you are trying to use Python with the Windows Scripting Host, note that .pys files are not correct registered - you will need to explicitly specify either cscript.exe or wscript.exe on the command line.